@@ -46,7 +46,7 @@
 #' the shock variable. The rows of each shown matrix then denotes the endogenous variable that reacts to the shock.}
 #'
 #'\item{specs}{A list with properties of \emph{endog_data} for the plot function. It also contains
-#'             lagged data (y_lin and x_lin) used for the irf estimations.}
+#'             lagged data (y_lin and x_lin) used for the irf estimations, and the selected lag lengths when an information criterion has been used.}
 #'
 #' @export
 #' @references
@@ -64,7 +64,7 @@
 #' Schwarz, Gideon E. (1978). "Estimating the dimension of a model", \emph{Annals of Statistics}, 6 (2): 461–464.
 #'
 #' @author Philipp Adämmer
-#' @importFrom foreach foreach
+#' @import foreach
 #' @examples
 #'\donttest{
 #'           ## Example without exogenous variables
@@ -318,7 +318,7 @@ lp_lin <- function(endog_data,
  # Make list to store OLS diagnostics for each horizon
   diagnost_ols_each_h <- list()
 
- # Make matrix to store OLS diagnostics for each endogenous variable k
+  # Make matrix to store OLS diagnostics for each endogenous variable k
   diagnost_each_k           <- matrix(NaN, specs$endog,  4)
   rownames(diagnost_each_k) <- specs$column_names
   colnames(diagnost_each_k) <- c("R-sqrd.", "Adj. R-sqrd.", "F-stat", " p-value")
@@ -431,6 +431,14 @@ lp_lin <- function(endog_data,
                                          'AIC' = 2,
                                          'BIC' = 3)
 
+  # Make list to store chosen lags
+  chosen_lags <- list()
+
+  # Make matrix to store selected lags
+  chosen_lags_k             <- matrix(NaN, specs$endog,  1)
+  names(diagnost_each_k)    <- specs$column_names
+
+
  # Loops to estimate local projections.
   lin_irfs <- foreach(s          = 1:specs$endog,
                      .packages   = 'lpirfs')  %dopar% {
@@ -477,13 +485,17 @@ lp_lin <- function(endog_data,
          b1_low[k, ]    <-   b[2:(specs$endog + 1)] - std_err[2:(specs$endog + 1)]
          b1_up[k, ]     <-   b[2:(specs$endog + 1)] + std_err[2:(specs$endog + 1)]
 
-         # Get diagnostocs for summary
+         # Get diagnostics for summary
          get_diagnost              <- lpirfs::ols_diagnost(yy, xx)
          diagnost_each_k[k, 1]     <- get_diagnost[[3]]
          diagnost_each_k[k, 2]     <- get_diagnost[[4]]
          diagnost_each_k[k, 3]     <- get_diagnost[[5]]
          diagnost_each_k[k, 4]     <- stats::pf(diagnost_each_k[k, 3], get_diagnost[[6]], get_diagnost[[7]], lower.tail = F)
 
+         # Save chosen lag length
+         chosen_lags_k[k] <- lag_choice
+
+
        }
 
 
@@ -494,17 +506,20 @@ lp_lin <- function(endog_data,
 
          # Save full summary matrix in list for each horizon
          diagnost_ols_each_h[[h]]        <- diagnost_each_k
+         chosen_lags[[h]]                <- chosen_lags_k
 
     }
 
      # Give names to horizon
        names(diagnost_ols_each_h)    <- paste("h", 1:specs$hor, sep = " ")
+       names(chosen_lags)            <- paste("h", 1:specs$hor, sep = " ")
 
-      return(list(irf_mean,  irf_low,  irf_up, diagnost_ols_each_h))
+       return(list(irf_mean,  irf_low,  irf_up, diagnost_ols_each_h, chosen_lags))
     }
 
 
     diagnostic_list      <- list()
+    chosen_lags_list     <- list()
 
     # Fill arrays with irfs
     for(i in 1:specs$endog){
@@ -521,11 +536,14 @@ lp_lin <- function(endog_data,
 
       # Fill list with all OLS diagnostics
       diagnostic_list[[i]]        <- lin_irfs[[i]][4]
+      chosen_lags_list[[i]]       <- lin_irfs[[i]][5]
 
     }
 
     # Give names to diagnostic List
-    names(diagnostic_list) <- paste("Shock:", specs$column_names, sep = " ")
+    names(diagnostic_list)  <- paste("Shock:", specs$column_names, sep = " ")
+    names(chosen_lags_list) <- paste("Shock:", specs$column_names, sep = " ")
+    specs$chosen_lags       <- chosen_lags_list
 
 
 ###################################################################################################
